#
# spec file for package python-astor
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-astor
Version:        0.8.1
Release:        lp152.3.1
Summary:        Read/rewrite/write Python ASTs
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/berkerpeksag/astor
Source:         https://github.com/berkerpeksag/astor/archive/%{version}.tar.gz#/astor-%{version}.tar.gz
# https://github.com/berkerpeksag/astor/pull/177
Patch0:         remove_nose.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module unittest2}
# /SECTION
%python_subpackages

%description
astor is designed to allow easy manipulation of Python source via the AST.
There are some other similar libraries, but astor focuses on the following areas:
- Round-trip an AST back to Python:
  - Modified AST doesn't need linenumbers, ctx, etc. or otherwise
    be directly compileable for the round-trip to work.
  - Easy to read generated code as, well, code
  - Can round-trip two different source trees to compare for functional
    differences, using the astor.rtrip tool (for example, after PEP8 edits).
- Dump pretty-printing of AST
  - Harder to read than round-tripped code, but more accurate to figure out what
    is going on.
  - Easier to read than dump from built-in AST module
- Non-recursive treewalk
  - Sometimes you want a recursive treewalk (and astor supports that, starting
    at any node on the tree), but sometimes you don't need to do that.  astor
    doesn't require you to explicitly visit sub-nodes unless you want to:
  - You can add code that executes before a node's children are visited, and/or
  - You can add code that executes after a node's children are visited, and/or
  - You can add code that executes and keeps the node's children from being
    visited (and optionally visit them yourself via a recursive call)
  - Write functions to access the tree based on object names and/or attribute names
  - Enjoy easy access to parent node(s) for tree rewriting

%prep
%setup -q -n astor-%{version}
%patch0 -p1

%build
# ugly fix for the use of /usr/bin/env
sed -i 's@#!.*@@' astor/rtrip.py
chmod a-x astor/rtrip.py
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
# fix executeable bits
%python_expand chmod 755 %{buildroot}%{$python_sitelib}/astor/rtrip.py

%check
%python_exec -m unittest2 discover -v

%files %{python_files}
%doc AUTHORS README.rst docs/*.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Fri Apr  3 2020 Marcus Rueckert <mrueckert@suse.de>
- remove the shebang line from the rtrip.py otherwise the python3
  package will require /usr/bin/python.
* Wed Mar 25 2020 Paolo Stivanin <info@paolostivanin.com>
- Add remove_nose.patch
  * test suite runs fine without nose, because it was written for unittest2
    and, because nose won't work with Python 3.9/3.10, this patch removes
    the requirement from setup.cfg and use unittest2 in the spec file
    instead of nose
* Fri Jan 17 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.8.1
  * Create sdist before making a test release too
  * remove expr_text handler from fstrings
- Drop obsolete python38.patch and setuptools-gt-41_1.patch
* Thu Nov 14 2019 Matej Cepl <mcepl@suse.com>
- Add patch to build with setuptools >= 41.4:
  * setuptools-gt-41_1.patch
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to build with py 3.8:
  * python38.patch
* Mon Jun  3 2019 pgajdos@suse.com
- version update to 0.8
  * Support ``ast.Constant`` nodes being emitted by Python 3.8 (and initially
    created in Python 3.6).
    (Reported and fixed by Chris Rink in `Issue 120`_ and `PR 121`_.)
  * Support Python 3.8's assignment expressions.
    (Reported and fixed by Kodi Arfer in `Issue 126`_ and `PR 134`_.)
  * Support Python 3.8's f-string debugging syntax.
    (Reported and fixed by Batuhan Taskaya in `Issue 138`_ and `PR 139`_.)
  * :func:`astor.to_source` now has a *source_generator_class* parameter to
    customize source code generation.
    (Reported and fixed by matham in `Issue 113`_ and `PR 114`_.)
  * The :class:`~SourceGenerator` class can now be imported from the
    :mod:`astor` package directly. Previously, the ``astor.code_gen``
    submodule was needed to be imported.
  * Support Python 3.8's positional only arguments. See :pep:`570` for
    more details.
    (Reported and fixed by Batuhan Taskaya in `Issue 142`_ and `PR 143`_.)
  * bug fixes, see changelog.rst
- run the testsuite
* Fri Nov  9 2018 Petr Cervinka <petr@cervinka.net>
- Removed copied link reference from spec file
* Fri Nov  9 2018 cgoll@suse.com
- fixed rpmlint warnings
* Thu Nov  8 2018 cgoll@suse.com
- removed not needed module devel
  * removed check section
  * using license macro
* Wed Jul 25 2018 cgoll@suse.com
- initial commit of astor 0.7.1 for python2 and python3
  * skipped check section, as this was faling
